#ifndef _CONSOLE_TERMINAL_H
#define _CONSOLE_TERMINAL_H

#define ARRAY_NUMELEM(A)	(sizeof((A))/sizeof((A)[0]))

#define MAX_COMMAND_LENGTH    16
#define MAX_ARG_LENGTH        32

// Command line structure and type
enum e_CommandKey
{
  _INVALID=-3,
  _NOP, _EMPTY,
  _HELP,
  _CLS,
  _P,
  _L,
  _T,
  _TF,
  _R,
  _RF,
  _E,
  _C,
  _FILES,
  _CHDIR,
  _DISPLAY,
  _DISPLAY_BOX,
  _SLIDE,
  _CLR,
  _BAUD,
  _TOUCH_SENS,
};
typedef enum e_CommandKey CommandKey;

struct s_CommandLine
{
  CommandKey Key;
  char Name[MAX_COMMAND_LENGTH];
  int ParamNum;
};
typedef struct s_CommandLine CommandLine;

extern CommandLine  Commands[];
extern int NumberCommands, SDCardError, BaudRateKey, Touch_Threshold;

/*******************************************************************************
 * Function Name: NewLine
 * Parameters:  None
 *
 * Return: None
 *
 * Desrpition: Print a new line at the console terminal.
 *
 ******************************************************************************/
void NewLine (void);

/*******************************************************************************
 * Function Name: ReadLn
 * Parameters:  Line - the string that keep the input string
 *
 * Return: int 0 - no new line(enter)
 *             1 - new line (enter is pressed).
 *
 * Desrpition: Continiously reading symbols from the UART0 and but them into a 
 *             <Buffer> and when enter is pressed all the bytes are copied to
 *             <Line> (the input parameter). In that case the next input starts
 *             from the begining.
 *
 ******************************************************************************/
int ReadLn (char Line[]);

/*******************************************************************************
 * Function Name: Write
 * Parameters:  Line - the string to be printed.
 *
 * Return: None
 *
 * Desrpition: Print the string on the console terminal.
 *
 ******************************************************************************/
void Write (char Line[]);

/*******************************************************************************
 * Function Name: Write
 * Parameters:  Line - the string to be printed.
 *
 * Return: None
 *
 * Desrpition:  Print the string on the console terminal and add a new line at
 *              the end of the text.
 *
 ******************************************************************************/
void WriteLn (char Line[]);

CommandKey Form_Command (char Input[], int *argc, char ***argv);

void Dispatch_Command (CommandKey Key, int argc, char **argv);

#endif